==> flutter_p2p_engine-1.0.0.tar.gz: README.md <==
**English | [简体中文](Readme_zh.md)**

<h1 align="center"><a href="" target="_blank" rel="noopener noreferrer"><img width="250" src="https://www.cdnbye.com/logo.png" alt="logo"></a></h1>
<h4 align="center">Live/VOD P2P Engine for Flutter</h4>
<p align="center">
<a href="https://pub.dartlang.org/packages/flutter_p2p_engine"><img src="https://img.shields.io/pub/v/flutter_p2p_engine.svg" alt="pub"></a>
</p>

## Features
- Support iOS, macOS and Android platform
- Support live and VOD streams over HLS protocol and MPEG-Dash(Android only)
- Support encrypted HLS stream
- Support cache to avoid repeating the download of TS file
- Very easy to integrate with an existing flutter project
- Support any flutter player
- Highly configurable
- Use IP database to group up peers by ISP and regions

## Usage
See [documentation](https://p2p.cdnbye.com/en/views/flutter/usage.html)

## Request Token
See [here](https://p2p.cdnbye.com/en/views/bindings.html#app-id-and-token)

## Consloe
Register your AppId at https://oms.cdnbye.com, where you can view p2p-related information.

## Issue & Feature Request
- If you found a bug, open an issue.
- If you have a feature request, open an issue.

## Related Projects
- [hlsjs-p2p-engine](https://github.com/cdnbye/hlsjs-p2p-engine) - Web Video Delivery Technology with No Plugins.
- [ios-p2p-engine](https://github.com/cdnbye/ios-p2p-engine) -  iOS Video P2P Engine for Any Player.
- [android-p2p-engine](https://github.com/cdnbye/android-p2p-engine) -  iOS Video P2P Engine for Any Player.

## FAQ
We have collected some [frequently asked questions](https://p2p.cdnbye.com/en/views/FAQ.html). Before reporting an issue, please search if the FAQ has the answer to your problem.

## Contact Us
Email：service@cdnbye.com
<br>
Telegram: @cdnbye
<br>
Skype: live:86755838

==> flutter_p2p_engine-1.1.0.tar.gz: README.md <==
**English | [简体中文](Readme_zh.md)**

<h1 align="center"><a href="" target="_blank" rel="noopener noreferrer"><img width="250" src="https://www.cdnbye.com/logo.png" alt="logo"></a></h1>
<h4 align="center">Live/VOD P2P Engine for Flutter</h4>
<p align="center">
<a href="https://pub.dartlang.org/packages/flutter_p2p_engine"><img src="https://img.shields.io/pub/v/flutter_p2p_engine.svg" alt="pub"></a>
</p>

## Features
- Support iOS, macOS and Android platform
- Support live and VOD streams over HLS protocol and MPEG-Dash(Android only)
- Support encrypted HLS stream
- Support cache to avoid repeating the download of TS file
- Very easy to integrate with an existing flutter project
- Support any flutter player
- Highly configurable
- Use IP database to group up peers by ISP and regions

## Usage
See [documentation](https://www.cdnbye.com/en/views/flutter/usage.html)

## Request Token
See [here](https://www.cdnbye.com/en/views/bindings.html#app-id-and-token)

## Consloe
Register your AppId at https://oms.cdnbye.com, where you can view p2p-related information.

## Issue & Feature Request
- If you found a bug, open an issue.
- If you have a feature request, open an issue.

## Related Projects
- [hlsjs-p2p-engine](https://github.com/cdnbye/hlsjs-p2p-engine) - Web Video Delivery Technology with No Plugins.
- [ios-p2p-engine](https://github.com/cdnbye/ios-p2p-engine) -  iOS Video P2P Engine for Any Player.
- [android-p2p-engine](https://github.com/cdnbye/android-p2p-engine) -  iOS Video P2P Engine for Any Player.

## FAQ
We have collected some [frequently asked questions](https://www.cdnbye.com/en/views/FAQ.html). Before reporting an issue, please search if the FAQ has the answer to your problem.

## Contact Us
Email：service@cdnbye.com
<br>
Telegram: @cdnbye
<br>
Skype: live:86755838
